@@ -2,14 +2,15 @@
 
 import click
 
-import osxphotos
 from osxphotos._version import __version__
 
 from .about import about
 from .albums import albums
 from .common import DB_OPTION, JSON_OPTION, OSXPHOTOS_HIDDEN
 from .debug_dump import debug_dump
+from .docs import docs
 from .dump import dump
+from .exiftool_cli import exiftool
 from .export import export
 from .exportdb import exportdb
 from .grep import grep
@@ -18,21 +19,22 @@ from .info import info
 from .install_uninstall_run import install, run, uninstall
 from .keywords import keywords
 from .labels import labels
-from .list import _list_libraries, list_libraries
+from .list import list_libraries
 from .persons import persons
 from .places import places
 from .query import query
 from .repl import repl
 from .snap_diff import diff, snap
+from .theme import theme
+from .timewarp import timewarp
 from .tutorial import tutorial
 from .uuid import uuid
+from .version import version
 
 
 # Click CLI object & context settings
 class CLI_Obj:
     def __init__(self, db=None, json=False, debug=False, group=None):
-        if debug:
-            osxphotos._set_debug(True)
         self.db = db
         self.json = json
         self.group = group
@@ -54,6 +56,7 @@ CTX_SETTINGS = dict(help_option_names=["-h", "--help"])
 @click.version_option(__version__, "--version", "-v")
 @click.pass_context
 def cli_main(ctx, db, json_, debug):
+    """osxphotos: query and export your Photos library"""
     ctx.obj = CLI_Obj(db=db, json=json_, group=cli_main)
 
 
@@ -63,7 +66,9 @@ for command in [
     albums,
     debug_dump,
     diff,
+    docs,
     dump,
+    exiftool,
     export,
     exportdb,
     grep,
@@ -77,9 +82,13 @@ for command in [
     places,
     query,
     repl,
+    run,
     snap,
+    theme,
+    timewarp,
     tutorial,
     uninstall,
     uuid,
+    version,
 ]:
     cli_main.add_command(command)
