@@ -1,22 +1,21 @@
 """Globals and constants use by the CLI commands"""
 
-import datetime
+
 import os
 import pathlib
-import typing as t
+from datetime import datetime
 
 import click
+from packaging import version
+from xdg import xdg_config_home, xdg_data_home
 
 import osxphotos
+from osxphotos._constants import APP_NAME
 from osxphotos._version import __version__
+from osxphotos.utils import get_latest_version
 
-from .click_rich_echo import rich_echo
 from .param_types import *
 
-# global variable to control debug output
-# set via --debug
-DEBUG = False
-
 # used to show/hide hidden commands
 OSXPHOTOS_HIDDEN = not bool(os.getenv("OSXPHOTOS_SHOW_HIDDEN", default=False))
 
@@ -24,21 +23,26 @@ OSXPHOTOS_HIDDEN = not bool(os.getenv("OSXPHOTOS_SHOW_HIDDEN", default=False))
 OSXPHOTOS_SNAPSHOT_DIR = "/private/tmp/osxphotos_snapshots"
 
 # where to write the crash report if osxphotos crashes
-OSXPHOTOS_CRASH_LOG = os.getcwd() + "/osxphotos_crash.log"
+OSXPHOTOS_CRASH_LOG = f"{os.getcwd()}/osxphotos_crash.log"
 
 CLI_COLOR_ERROR = "red"
 CLI_COLOR_WARNING = "yellow"
 
-
-def set_debug(debug: bool):
-    """set debug flag"""
-    global DEBUG
-    DEBUG = debug
-
-
-def is_debug():
-    """return debug flag"""
-    return DEBUG
+__all__ = [
+    "CLI_COLOR_ERROR",
+    "CLI_COLOR_WARNING",
+    "DB_ARGUMENT",
+    "DB_OPTION",
+    "DEBUG_OPTIONS",
+    "DELETED_OPTIONS",
+    "JSON_OPTION",
+    "QUERY_OPTIONS",
+    "THEME_OPTION",
+    "get_photos_db",
+    "load_uuid_from_file",
+    "noop",
+    "time_stamp",
+]
 
 
 def noop(*args, **kwargs):
@@ -46,53 +50,9 @@ def noop(*args, **kwargs):
     pass
 
 
-def verbose_print(
-    verbose: bool = True, timestamp: bool = False, rich=False, **kwargs: t.Any
-) -> t.Callable:
-    """Create verbose function to print output
-
-    Args:
-        verbose: if True, returns verbose print function otherwise returns no-op function
-        timestamp: if True, includes timestamp in verbose output
-        rich: use rich.print instead of click.echo
-        kwargs: any extra arguments to pass to click.echo or rich.print depending on whether rich==True
-
-    Returns:
-        function to print output
-    """
-    if not verbose:
-        return noop
-
-    # closure to capture timestamp
-    def verbose_(*args):
-        """print output if verbose flag set"""
-        styled_args = []
-        timestamp_str = f"{str(datetime.datetime.now())} -- " if timestamp else ""
-        for arg in args:
-            if type(arg) == str:
-                arg = timestamp_str + arg
-                if "error" in arg.lower():
-                    arg = click.style(arg, fg=CLI_COLOR_ERROR)
-                elif "warning" in arg.lower():
-                    arg = click.style(arg, fg=CLI_COLOR_WARNING)
-            styled_args.append(arg)
-        click.echo(*styled_args, **kwargs)
-
-    def rich_verbose_(*args):
-        """print output if verbose flag set using rich.print"""
-        timestamp_str = f"{str(datetime.datetime.now())} -- " if timestamp else ""
-        new_args = []
-        for arg in args:
-            if type(arg) == str:
-                arg = timestamp_str + arg
-                if "error" in arg.lower():
-                    arg = f"[{CLI_COLOR_ERROR}]{arg}[/{CLI_COLOR_ERROR}]"
-                elif "warning" in arg.lower():
-                    arg = f"[{CLI_COLOR_WARNING}]{arg}[/{CLI_COLOR_WARNING}]"
-            new_args.append(arg)
-        rich_echo(*new_args, **kwargs)
-
-    return rich_verbose_ if rich else verbose_
+def time_stamp() -> str:
+    """return timestamp"""
+    return f"[time]{str(datetime.now())}[/time] -- "
 
 
 def get_photos_db(*db_options):
@@ -128,10 +88,12 @@ def get_photos_db(*db_options):
         return None
 
 
+VERSION_CHECK_OPTION = click.option("--no-version-check", required=False, is_flag=True)
+
 DB_OPTION = click.option(
     "--db",
     required=False,
-    metavar="<Photos database path>",
+    metavar="PHOTOS_LIBRARY_PATH",
     default=None,
     help=(
         "Specify Photos database path. "
@@ -185,6 +147,11 @@ def QUERY_OPTIONS(f):
             help="Search for photos with keyword KEYWORD. "
             'If more than one keyword, treated as "OR", e.g. find photos matching any keyword',
         ),
+        o(
+            "--no-keyword",
+            is_flag=True,
+            help="Search for photos with no keyword.",
+        ),
         o(
             "--person",
             metavar="PERSON",
@@ -411,6 +378,39 @@ def QUERY_OPTIONS(f):
             help="Search by item end time of day, e.g. 12:00 or 12:00:00.",
             type=TimeISO8601(),
         ),
+        o(
+            "--year",
+            metavar="YEAR",
+            help="Search for items from a specific year, e.g. --year 2022 to find all photos from the year 2022. "
+            "May be repeated to search multiple years.",
+            multiple=True,
+            type=int,
+        ),
+        o(
+            "--added-before",
+            metavar="DATE",
+            help="Search for items added to the library before a specific date/time, "
+            "e.g. --added-before e.g. 2000-01-12T12:00:00, 2001-01-12T12:00:00-07:00, or 2000-12-31 (ISO 8601 with/without timezone).",
+            type=DateTimeISO8601(),
+        ),
+        o(
+            "--added-after",
+            metavar="DATE",
+            help="Search for items added to the libray after a specific date/time, "
+            "e.g. --added-after e.g. 2000-01-12T12:00:00, 2001-01-12T12:00:00-07:00, or 2000-12-31 (ISO 8601 with/without timezone).",
+            type=DateTimeISO8601(),
+        ),
+        o(
+            "--added-in-last",
+            metavar="TIME_DELTA",
+            help="Search for items added to the library in the last TIME_DELTA, "
+            "where TIME_DELTA is a string like "
+            "'12 hrs', '1 day', '1d', '1 week', '2weeks', '1 month', '1 year'. "
+            "for example, `--added-in-last 7d` and `--added-in-last '1 week'` are equivalent. "
+            "months are assumed to be 30 days and years are assumed to be 365 days. "
+            "Common English abbreviations are accepted, e.g. d, day, days or m, min, minutes.",
+            type=TimeOffset(),
+        ),
         o("--has-comment", is_flag=True, help="Search for photos that have comments."),
         o("--no-comment", is_flag=True, help="Search for photos with no comments."),
         o("--has-likes", is_flag=True, help="Search for photos that have likes."),
@@ -513,6 +513,47 @@ def QUERY_OPTIONS(f):
     return f
 
 
+def DEBUG_OPTIONS(f):
+    o = click.option
+    options = [
+        o(
+            "--debug",
+            is_flag=True,
+            help="Enable debug output.",
+            hidden=OSXPHOTOS_HIDDEN,
+        ),
+        o(
+            "--watch",
+            metavar="FUNCTION_PATH",
+            multiple=True,
+            help="Watch function calls.  For example, to watch all calls to FileUtil.copy: "
+            "'--watch osxphotos.fileutil.FileUtil.copy'.  More than one --watch option can be specified.",
+            hidden=OSXPHOTOS_HIDDEN,
+        ),
+        o(
+            "--breakpoint",
+            metavar="FUNCTION_PATH",
+            multiple=True,
+            help="Add breakpoint to function calls.  For example, to add breakpoint to FileUtil.copy: "
+            "'--breakpoint osxphotos.fileutil.FileUtil.copy'.  More than one --breakpoint option can be specified.",
+            hidden=OSXPHOTOS_HIDDEN,
+        ),
+    ]
+    for o in options[::-1]:
+        f = o(f)
+    return f
+
+
+THEME_OPTION = click.option(
+    "--theme",
+    metavar="THEME",
+    type=click.Choice(["dark", "light", "mono", "plain"], case_sensitive=False),
+    help="Specify the color theme to use for --verbose output. "
+    "Valid themes are 'dark', 'light', 'mono', and 'plain'. "
+    "Defaults to 'dark' or 'light' depending on system dark mode setting.",
+)
+
+
 def load_uuid_from_file(filename):
     """Load UUIDs from file.  Does not validate UUIDs.
         Format is 1 UUID per line, any line beginning with # is ignored.
@@ -538,3 +579,32 @@ def load_uuid_from_file(filename):
             if len(line) and line[0] != "#":
                 uuid.append(line)
     return uuid
+
+
+def get_config_dir() -> pathlib.Path:
+    """Get the directory where config files are stored; create it if necessary."""
+    config_dir = xdg_config_home() / APP_NAME
+    if not config_dir.is_dir():
+        config_dir.mkdir(parents=True)
+    return config_dir
+
+
+def get_data_dir() -> pathlib.Path:
+    """Get the director where local user data files are stored; create it if necessary"""
+    data_dir = xdg_data_home() / APP_NAME
+    if not data_dir.is_dir():
+        data_dir.mkdir(parents=True)
+    return data_dir
+
+
+def check_version():
+    """Check for updates"""
+    latest_version, _ = get_latest_version()
+    if latest_version and version.parse(latest_version) > version.parse(__version__):
+        click.echo(
+            f"New version {latest_version} available; you are running {__version__}\n"
+            "Run `pipx upgrade osxphotos` to upgrade.\n"
+            "Use --no-version-check or set environment variable OSXPHOTOS_NO_VERSION_CHECK=1 "
+            "to suppress this message and prevent osxphotos from checking for latest version.",
+            err=True,
+        )
