@@ -2,16 +2,22 @@
 
 
 import datetime
+import gzip
 import json
 import logging
 import os
 import pathlib
+import pickle
 import sqlite3
 import sys
+import time
+from contextlib import suppress
 from io import StringIO
 from sqlite3 import Error
 from tempfile import TemporaryDirectory
-from typing import Optional, Tuple, Union
+from typing import Any, Optional, Tuple, Union, List
+
+from tenacity import retry, stop_after_attempt
 
 from ._constants import OSXPHOTOS_EXPORT_DB
 from ._version import __version__
@@ -24,9 +30,42 @@ __all__ = [
     "ExportDBTemp",
 ]
 
-OSXPHOTOS_EXPORTDB_VERSION = "6.0"
+OSXPHOTOS_EXPORTDB_VERSION = "7.0"
 OSXPHOTOS_ABOUT_STRING = f"Created by osxphotos version {__version__} (https://github.com/RhetTbull/osxphotos) on {datetime.datetime.now()}"
 
+# max retry attempts for methods which use tenacity.retry
+MAX_RETRY_ATTEMPTS = 5
+
+# maximum number of export results rows to save
+MAX_EXPORT_RESULTS_DATA_ROWS = 10
+
+
+def pickle_and_zip(data: Any) -> bytes:
+    """
+    Pickle and gzip data.
+
+    Args:
+        data: data to pickle and gzip (must be pickle-able)
+
+    Returns:
+        bytes of gzipped pickled data
+    """
+    pickled = pickle.dumps(data)
+    return gzip.compress(pickled)
+
+
+def unzip_and_unpickle(data: bytes) -> Any:
+    """
+    Unzip and unpickle data.
+
+    Args:
+        data: data to unzip and unpickle
+
+    Returns:
+        unpickled data
+    """
+    return pickle.loads(gzip.decompress(data))
+
 
 class ExportDB:
     """Interface to sqlite3 database used to store state information for osxphotos export command"""
@@ -63,20 +102,19 @@ class ExportDB:
     def get_file_record(self, filename: Union[pathlib.Path, str]) -> "ExportRecord":
         """get info for filename and uuid
 
-        Returns: an ExportRecord object
+        Returns: an ExportRecord object or None if filename not found
         """
         filename = self._relative_filepath(filename)
         filename_normalized = self._normalize_filepath(filename)
         conn = self._conn
         c = conn.cursor()
-        row = c.execute(
+
+        if _ := c.execute(
             "SELECT uuid FROM export_data WHERE filepath_normalized = ?;",
             (filename_normalized,),
-        ).fetchone()
-
-        if not row:
-            return None
-        return ExportRecord(conn, filename_normalized)
+        ).fetchone():
+            return ExportRecord(conn, filename_normalized)
+        return None
 
     def create_file_record(
         self, filename: Union[pathlib.Path, str], uuid: str
@@ -133,6 +171,17 @@ class ExportDB:
             uuid = None
         return uuid
 
+    def get_files_for_uuid(self, uuid: str) -> List:
+        """query database for UUID and return list of files associated with UUID or empty list"""
+        conn = self._conn
+        c = conn.cursor()
+        c.execute(
+            "SELECT filepath FROM export_data WHERE uuid = ?",
+            (uuid,),
+        )
+        results = c.fetchall()
+        return [os.path.join(self.export_dir, r[0]) for r in results]
+
     def get_photoinfo_for_uuid(self, uuid):
         """returns the photoinfo JSON struct for a UUID"""
         conn = self._conn
@@ -187,6 +236,77 @@ class ExportDB:
         except Error as e:
             logging.warning(e)
 
+    def set_export_results(self, results):
+        """Store export results in database; data is pickled and gzipped for storage"""
+
+        results_data = pickle_and_zip(results)
+
+        conn = self._conn
+        try:
+            dt = datetime.datetime.now().isoformat()
+            c = conn.cursor()
+            c.execute(
+                """
+                UPDATE export_results_data
+                SET datetime = ?,
+                    export_results = ?
+                WHERE datetime = (SELECT MIN(datetime) FROM export_results_data);
+                """,
+                (dt, results_data),
+            )
+            conn.commit()
+        except Error as e:
+            logging.warning(e)
+
+    def get_export_results(self, run: int = 0):
+        """Retrieve export results from database
+
+        Args:
+            run: which run to retrieve results for;
+            0 = most recent run, -1 = previous run, -2 = run prior to that, etc.
+
+        Returns:
+            ExportResults object or None if no results found
+        """
+        if run > 0:
+            raise ValueError("run must be 0 or negative")
+        run = -run
+
+        conn = self._conn
+        try:
+            c = conn.cursor()
+            c.execute(
+                """
+                SELECT export_results
+                FROM export_results_data
+                ORDER BY datetime DESC
+                """,
+            )
+            rows = c.fetchall()
+            try:
+                data = rows[run][0]
+                results = unzip_and_unpickle(data) if data else None
+            except IndexError:
+                results = None
+        except Error as e:
+            logging.warning(e)
+            results = None
+        return results
+
+    def get_exported_files(self):
+        """Returns tuple of (uuid, filepath) for all paths of all exported files tracked in the database"""
+        conn = self._conn
+        try:
+            c = conn.cursor()
+            c.execute("SELECT uuid, filepath FROM export_data")
+        except Error as e:
+            logging.warning(e)
+            return
+
+        while row := c.fetchone():
+            yield row[0], os.path.join(self.export_dir, row[1])
+        return
+
     def close(self):
         """close the database connection"""
         try:
@@ -204,7 +324,7 @@ class ExportDB:
         if not os.path.isfile(dbfile):
             conn = self._get_db_connection(dbfile)
             if not conn:
-                raise Exception("Error getting connection to database {dbfile}")
+                raise Exception(f"Error getting connection to database {dbfile}")
             self._create_or_migrate_db_tables(conn)
             self.was_created = True
             self.was_upgraded = ()
@@ -357,18 +477,20 @@ class ExportDB:
             # create export_data table
             self._migrate_5_0_to_6_0(conn)
 
+        if version[1] < "7.0":
+            # create report_data table
+            self._migrate_6_0_to_7_0(conn)
+
         conn.execute("VACUUM;")
         conn.commit()
 
     def __del__(self):
         """ensure the database connection is closed"""
-        try:
+        with suppress(Exception):
             self._conn.close()
-        except:
-            pass
 
     def _insert_run_info(self):
-        dt = datetime.datetime.utcnow().isoformat()
+        dt = datetime.datetime.now(datetime.timezone.utc).isoformat()
         python_path = sys.executable
         cmd = sys.argv[0]
         args = " ".join(sys.argv[1:]) if len(sys.argv) > 1 else ""
@@ -553,6 +675,29 @@ class ExportDB:
         except Error as e:
             logging.warning(e)
 
+    def _migrate_6_0_to_7_0(self, conn):
+        try:
+            c = conn.cursor()
+            c.execute(
+                """CREATE TABLE IF NOT EXISTS export_results_data (
+                        id INTEGER PRIMARY KEY,
+                        datetime TEXT,
+                        export_results BLOB
+                );"""
+            )
+            # pre-populate report_data table with blank fields
+            # ExportDB will use these as circular buffer always writing to the oldest record
+            for _ in range(MAX_EXPORT_RESULTS_DATA_ROWS):
+                c.execute(
+                    """INSERT INTO export_results_data (datetime, export_results) VALUES (?, ?);""",
+                    (datetime.datetime.now().isoformat(), b""),
+                )
+                # sleep a tiny bit just to ensure time stamps increment
+                time.sleep(0.001)
+            conn.commit()
+        except Error as e:
+            logging.warning(e)
+
     def _perform_db_maintenace(self, conn):
         """Perform database maintenance"""
         try:
@@ -593,6 +738,7 @@ class ExportDBInMemory(ExportDB):
         self._conn = self._open_export_db(self._dbfile)
         self._insert_run_info()
 
+    @retry(stop=stop_after_attempt(MAX_RETRY_ATTEMPTS))
     def write_to_disk(self):
         """Write changes from in-memory database back to disk"""
 
@@ -626,7 +772,7 @@ class ExportDBInMemory(ExportDB):
         except Error as e:
             logging.warning(e)
 
-    def _open_export_db(self, dbfile):
+    def _open_export_db(self, dbfile):  # sourcery skip: raise-specific-error
         """open export database and return a db connection
         returns: connection to the database
         """
@@ -677,10 +823,8 @@ class ExportDBInMemory(ExportDB):
 
     def __del__(self):
         """close the database connection"""
-        try:
+        with suppress(Error):
             self.close()
-        except Error as e:
-            pass
 
 
 class ExportDBTemp(ExportDBInMemory):
@@ -720,11 +864,10 @@ class ExportRecord:
         """return filepath"""
         conn = self._conn
         c = conn.cursor()
-        row = c.execute(
+        if row := c.execute(
             "SELECT filepath FROM export_data WHERE filepath_normalized = ?;",
             (self._filepath_normalized,),
-        ).fetchone()
-        if row:
+        ).fetchone():
             return row[0]
 
         raise ValueError(
@@ -741,11 +884,10 @@ class ExportRecord:
         """return uuid"""
         conn = self._conn
         c = conn.cursor()
-        row = c.execute(
+        if row := c.execute(
             "SELECT uuid FROM export_data WHERE filepath_normalized = ?;",
             (self._filepath_normalized,),
-        ).fetchone()
-        if row:
+        ).fetchone():
             return row[0]
 
         raise ValueError(f"No uuid found in database for {self._filepath_normalized}")
@@ -755,11 +897,10 @@ class ExportRecord:
         """returns the digest value"""
         conn = self._conn
         c = conn.cursor()
-        row = c.execute(
+        if row := c.execute(
             "SELECT digest FROM export_data WHERE filepath_normalized = ?;",
             (self._filepath_normalized,),
-        ).fetchone()
-        if row:
+        ).fetchone():
             return row[0]
 
         raise ValueError(f"No digest found in database for {self._filepath_normalized}")
@@ -781,11 +922,10 @@ class ExportRecord:
         """returns exifdata value for record"""
         conn = self._conn
         c = conn.cursor()
-        row = c.execute(
+        if row := c.execute(
             "SELECT exifdata FROM export_data WHERE filepath_normalized = ?;",
             (self._filepath_normalized,),
-        ).fetchone()
-        if row:
+        ).fetchone():
             return row[0]
 
         raise ValueError(
@@ -812,11 +952,10 @@ class ExportRecord:
         """return source file signature value"""
         conn = self._conn
         c = conn.cursor()
-        row = c.execute(
+        if row := c.execute(
             "SELECT src_mode, src_size, src_mtime FROM export_data WHERE filepath_normalized = ?;",
             (self._filepath_normalized,),
-        ).fetchone()
-        if row:
+        ).fetchone():
             mtime = int(row[2]) if row[2] is not None else None
             return (row[0], row[1], mtime)
 
@@ -846,11 +985,10 @@ class ExportRecord:
         """return destination file signature"""
         conn = self._conn
         c = conn.cursor()
-        row = c.execute(
+        if row := c.execute(
             "SELECT dest_mode, dest_size, dest_mtime FROM export_data WHERE filepath_normalized = ?;",
             (self._filepath_normalized,),
-        ).fetchone()
-        if row:
+        ).fetchone():
             mtime = int(row[2]) if row[2] is not None else None
             return (row[0], row[1], mtime)
 
@@ -937,6 +1075,10 @@ class ExportRecord:
             "photoinfo": photoinfo,
         }
 
+    def json(self, indent=None):
+        """Return json of self"""
+        return json.dumps(self.asdict(), indent=indent)
+
     def __enter__(self):
         self._context_manager = True
         return self
