@@ -11,6 +11,7 @@ import os
 import os.path
 import pathlib
 from datetime import timedelta, timezone
+from functools import cached_property
 from typing import Optional
 
 import yaml
@@ -54,7 +55,7 @@ from .scoreinfo import ScoreInfo
 from .searchinfo import SearchInfo
 from .text_detection import detect_text
 from .uti import get_preferred_uti_extension, get_uti_for_extension
-from .utils import _debug, _get_resource_loc, list_directory, _debug
+from .utils import _get_resource_loc, hexdigest, list_directory
 
 __all__ = ["PhotoInfo", "PhotoInfoNone"]
 
@@ -479,7 +480,7 @@ class PhotoInfo:
             return self._faceinfo
 
     @property
-    def moment(self):
+    def moment_info(self):
         """Moment photo belongs to"""
         try:
             return self._moment
@@ -892,38 +893,37 @@ class PhotoInfo:
 
         return photopath
 
-    @property
+    @cached_property
     def path_derivatives(self):
         """Return any derivative (preview) images associated with the photo as a list of paths, sorted by file size (largest first)"""
-        try:
-            return self._path_derivatives
-        except AttributeError:
-            if self._db._db_version <= _PHOTOS_4_VERSION:
-                self._path_derivatives = self._path_derivatives_4()
-                return self._path_derivatives
+        if self._db._db_version <= _PHOTOS_4_VERSION:
+            return self._path_derivatives_4()
 
-            directory = self._uuid[0]  # first char of uuid
-            derivative_path = (
-                pathlib.Path(self._db._library_path)
-                / "resources"
-                / "derivatives"
-                / directory
-            )
-            files = derivative_path.glob(f"{self.uuid}*.*")
-            files = sorted(files, reverse=True, key=lambda f: f.stat().st_size)
-            # return list of filename but skip .THM files (these are actually low-res thumbnails in JPEG format but with .THM extension)
-            derivatives = [
-                str(filename) for filename in files if filename.suffix != ".THM"
-            ]
-            if (
-                self.isphoto
-                and len(derivatives) > 1
-                and derivatives[0].endswith(".mov")
-            ):
-                derivatives[1], derivatives[0] = derivatives[0], derivatives[1]
+        if self.shared:
+            return self._path_derivatives_5_shared()
 
-            self._path_derivatives = derivatives
-            return self._path_derivatives
+        directory = self._uuid[0]  # first char of uuid
+        derivative_path = (
+            pathlib.Path(self._db._library_path) / f"resources/derivatives/{directory}"
+        )
+        files = list(derivative_path.glob(f"{self.uuid}*.*"))
+
+        # previews may be missing from derivatives path
+        # there are what appear to be low res thumbnails in the "masters" subfolder
+        thumb_path = (
+            pathlib.Path(self._db._library_path)
+            / f"resources/derivatives/masters/{directory}/{self.uuid}_4_5005_c.jpeg"
+        )
+        if thumb_path.exists():
+            files.append(thumb_path)
+
+        files = sorted(files, reverse=True, key=lambda f: f.stat().st_size)
+        # return list of filename but skip .THM files (these are actually low-res thumbnails in JPEG format but with .THM extension)
+        derivatives = [str(filename) for filename in files if filename.suffix != ".THM"]
+        if self.isphoto and len(derivatives) > 1 and derivatives[0].endswith(".mov"):
+            derivatives[1], derivatives[0] = derivatives[0], derivatives[1]
+
+        return derivatives
 
     def _path_derivatives_4(self):
         """Return paths to all derivative (preview) files for Photos <= 4"""
@@ -933,10 +933,7 @@ class PhotoInfo:
         folder_id, file_id = _get_resource_loc(modelid)
         derivatives_root = (
             pathlib.Path(self._db._library_path)
-            / "resources"
-            / "proxies"
-            / "derivatives"
-            / folder_id
+            / f"resources/proxies/derivatives/{folder_id}"
         )
 
         # photos appears to usually be in "00" subfolder but
@@ -961,6 +958,19 @@ class PhotoInfo:
         # didn't find a derivatives path
         return []
 
+    def _path_derivatives_5_shared(self):
+        """Return paths to all derivative (preview) files for shared iCloud photos in Photos >= 5"""
+        directory = self._uuid[0]  # first char of uuid
+        # only 1 derivative for shared photos and it's called 'UUID_4_5005_c.jpeg'
+        derivative_path = (
+            pathlib.Path(self._db._library_path)
+            / "resources/cloudsharing/resources/derivatives/masters"
+            / f"{directory}/{self.uuid}_4_5005_c.jpeg"
+        )
+        if derivative_path.exists():
+            return [str(derivative_path)]
+        return []
+
     @property
     def panorama(self):
         """Returns True if photo is a panorama, otherwise False"""
@@ -1356,6 +1366,12 @@ class PhotoInfo:
             self._exiftool = exiftool
             return self._exiftool
 
+    @cached_property
+    def hexdigest(self):
+        """Returns a unique digest of the photo's properties and metadata;
+        useful for detecting changes in any property/metadata of the photo"""
+        return hexdigest(self.json())
+
     def detected_text(self, confidence_threshold=TEXT_DETECTION_CONFIDENCE_THRESHOLD):
         """Detects text in photo and returns lists of results as (detected text, confidence)
 
@@ -1451,43 +1467,45 @@ class PhotoInfo:
         description_template=None,
         render_options: Optional[RenderOptions] = None,
     ):
-        """export photo
-        dest: must be valid destination path (or exception raised)
-        filename: (optional): name of exported picture; if not provided, will use current filename
-                    **NOTE**: if provided, user must ensure file extension (suffix) is correct.
-                    For example, if photo is .CR2 file, edited image may be .jpeg.
-                    If you provide an extension different than what the actual file is,
-                    export will print a warning but will export the photo using the
-                    incorrect file extension (unless use_photos_export is true, in which case export will
-                    use the extension provided by Photos upon export; in this case, an incorrect extension is
-                    silently ignored).
-                    e.g. to get the extension of the edited photo,
-                    reference PhotoInfo.path_edited
-        edited: (boolean, default=False); if True will export the edited version of the photo, otherwise exports the original version
-                (or raise exception if no edited version)
-        live_photo: (boolean, default=False); if True, will also export the associated .mov for live photos
-        raw_photo: (boolean, default=False); if True, will also export the associated RAW photo
-        export_as_hardlink: (boolean, default=False); if True, will hardlink files instead of copying them
-        overwrite: (boolean, default=False); if True will overwrite files if they already exist
-        increment: (boolean, default=True); if True, will increment file name until a non-existant name is found
-                    if overwrite=False and increment=False, export will fail if destination file already exists
-        sidecar_json: if set will write a json sidecar with data in format readable by exiftool
-                    sidecar filename will be dest/filename.json; includes exiftool tag group names (e.g. `exiftool -G -j`)
-        sidecar_exiftool: if set will write a json sidecar with data in format readable by exiftool
-                    sidecar filename will be dest/filename.json; does not include exiftool tag group names (e.g. `exiftool -j`)
-        sidecar_xmp: if set will write an XMP sidecar with IPTC data
-                    sidecar filename will be dest/filename.xmp
-        use_photos_export: (boolean, default=False); if True will attempt to export photo via applescript interaction with Photos
-        timeout: (int, default=120) timeout in seconds used with use_photos_export
-        exiftool: (boolean, default = False); if True, will use exiftool to write metadata to export file
-        returns list of full paths to the exported files
-        use_albums_as_keywords: (boolean, default = False); if True, will include album names in keywords
-        when exporting metadata with exiftool or sidecar
-        use_persons_as_keywords: (boolean, default = False); if True, will include person names in keywords
-        when exporting metadata with exiftool or sidecar
-        keyword_template: (list of strings); list of template strings that will be rendered as used as keywords
-        description_template: string; optional template string that will be rendered for use as photo description
-        render_options: an optional osxphotos.phototemplate.RenderOptions instance with options to pass to template renderer
+        """Export a photo
+
+        Args:
+            dest: must be valid destination path (or exception raised)
+            filename: (optional): name of exported picture; if not provided, will use current filename
+              **NOTE**: if provided, user must ensure file extension (suffix) is correct.
+              For example, if photo is .CR2 file, edited image may be .jpeg.
+              If you provide an extension different than what the actual file is,
+              export will print a warning but will export the photo using the
+              incorrect file extension (unless use_photos_export is true, in which case export will
+              use the extension provided by Photos upon export; in this case, an incorrect extension is
+              silently ignored).
+              e.g. to get the extension of the edited photo,
+              reference PhotoInfo.path_edited
+            edited: (boolean, default=False); if True will export the edited version of the photo, otherwise exports the original version
+              (or raise exception if no edited version)
+            live_photo: (boolean, default=False); if True, will also export the associated .mov for live photos
+            raw_photo: (boolean, default=False); if True, will also export the associated RAW photo
+            export_as_hardlink: (boolean, default=False); if True, will hardlink files instead of copying them
+            overwrite: (boolean, default=False); if True will overwrite files if they already exist
+            increment: (boolean, default=True); if True, will increment file name until a non-existant name is found
+              if overwrite=False and increment=False, export will fail if destination file already exists
+            sidecar_json: if set will write a json sidecar with data in format readable by exiftool
+              sidecar filename will be dest/filename.json; includes exiftool tag group names (e.g. `exiftool -G -j`)
+            sidecar_exiftool: if set will write a json sidecar with data in format readable by exiftool
+              sidecar filename will be dest/filename.json; does not include exiftool tag group names (e.g. `exiftool -j`)
+            sidecar_xmp: if set will write an XMP sidecar with IPTC data
+              sidecar filename will be dest/filename.xmp
+            use_photos_export: (boolean, default=False); if True will attempt to export photo via applescript interaction with Photos
+            timeout: (int, default=120) timeout in seconds used with use_photos_export
+            exiftool: (boolean, default = False); if True, will use exiftool to write metadata to export file
+            returns list of full paths to the exported files
+            use_albums_as_keywords: (boolean, default = False); if True, will include album names in keywords
+            when exporting metadata with exiftool or sidecar
+            use_persons_as_keywords: (boolean, default = False); if True, will include person names in keywords
+            when exporting metadata with exiftool or sidecar
+            keyword_template: (list of strings); list of template strings that will be rendered as used as keywords
+            description_template: string; optional template string that will be rendered for use as photo description
+            render_options: an optional osxphotos.phototemplate.RenderOptions instance with options to pass to template renderer
 
         Returns:
             list of photos exported
@@ -1512,8 +1530,8 @@ class PhotoInfo:
                 else:
                     uti = self.uti_edited if edited and self.uti_edited else self.uti
                     ext = get_preferred_uti_extension(uti)
-                    ext = "." + ext
-                filename = original_name.stem + "_edited" + ext
+                    ext = f".{ext}"
+                filename = f"{original_name.stem}_edited{ext}"
 
         options = ExportOptions(
             description_template=description_template,
