@@ -3,6 +3,7 @@
 import datetime
 import fnmatch
 import glob
+import hashlib
 import importlib
 import inspect
 import logging
@@ -17,11 +18,10 @@ import sys
 import unicodedata
 import urllib.parse
 from plistlib import load as plistload
-from typing import Callable, List, Union, Optional
+from typing import Callable, List, Optional, Tuple, Union
 
 import CoreFoundation
-import objc
-from Foundation import NSFileManager, NSPredicate, NSString
+import requests
 
 from ._constants import UNICODE_FORMAT
 
@@ -30,6 +30,7 @@ __all__ = [
     "expand_and_validate_filepath",
     "get_last_library_path",
     "get_system_library_path",
+    "hexdigest",
     "increment_filename_with_count",
     "increment_filename",
     "lineno",
@@ -39,18 +40,16 @@ __all__ = [
     "noop",
     "normalize_fs_path",
     "normalize_unicode",
+    "pluralize",
 ]
 
-_DEBUG = False
-
 
 logging.basicConfig(
     level=logging.DEBUG,
     format="%(asctime)s - %(levelname)s - %(filename)s - %(lineno)d - %(message)s",
 )
 
-if not _DEBUG:
-    logging.disable(logging.DEBUG)
+VERSION_INFO_URL = "https://pypi.org/pypi/osxphotos/json"
 
 
 def _get_logger():
@@ -62,21 +61,6 @@ def _get_logger():
     return logging.Logger(__name__)
 
 
-def _set_debug(debug):
-    """Enable or disable debug logging"""
-    global _DEBUG
-    _DEBUG = debug
-    if debug:
-        logging.disable(logging.NOTSET)
-    else:
-        logging.disable(logging.DEBUG)
-
-
-def _debug():
-    """returns True if debugging turned on (via _set_debug), otherwise, false"""
-    return _DEBUG
-
-
 def noop(*args, **kwargs):
     """do nothing (no operation)"""
     pass
@@ -270,8 +254,7 @@ def list_photo_libraries():
     )
 
     # On older OS, may not get all libraries so make sure we get the last one
-    last_lib = get_last_library_path()
-    if last_lib:
+    if last_lib := get_last_library_path():
         lib_list.append(last_lib)
 
     output = subprocess.check_output(
@@ -279,8 +262,7 @@ def list_photo_libraries():
     ).splitlines()
     for lib in output:
         lib_list.append(lib.decode("utf-8"))
-    lib_list = list(set(lib_list))
-    lib_list.sort()
+    lib_list = sorted(set(lib_list))
     return lib_list
 
 
@@ -505,8 +487,11 @@ def load_function(pyfile: str, function_name: str) -> Callable:
 
     try:
         func = getattr(module, function_name)
-    except AttributeError:
-        raise ValueError(f"'{function_name}' not found in module '{module_name}'")
+    except AttributeError as e:
+        raise ValueError(
+            f"'{function_name}' not found in module '{module_name}'"
+        ) from e
+
     finally:
         # restore sys.path
         sys.path = syspath
@@ -518,3 +503,26 @@ def format_sec_to_hhmmss(sec: float) -> str:
     """Format seconds to hh:mm:ss"""
     delta = datetime.timedelta(seconds=sec)
     return str(delta).split(".")[0]
+
+
+def get_latest_version() -> Tuple[Optional[str], str]:
+    """Get latest version of osxphotos or None if version can't be retrieved"""
+    try:
+        url = VERSION_INFO_URL
+        response = requests.get(url)
+        data = response.json()
+        return data["info"]["version"], ""
+    except Exception as e:
+        return None, e
+
+
+def pluralize(count: Optional[int], singular: str, plural: str) -> str:
+    """Return singular or plural based on count"""
+    return singular if count == 1 else plural
+
+
+def hexdigest(strval: str) -> str:
+    """hexdigest of a string, using blake2b"""
+    h = hashlib.blake2b(digest_size=20)
+    h.update(bytes(strval, "utf-8"))
+    return h.hexdigest()
